@@ -1,7 +1,8 @@
 from enum import Enum
 
 from .code_mappings import STATE_CODE_TO_STATUS, ERROR_CODE_TO_TEXT, FAN_SPEED_CODES, MOP_MODE_CODES, \
-    MOP_INTENSITY_CODES, DOCK_ERROR_TO_TEXT, DOCK_TYPE_MAP, RoborockDockType
+    MOP_INTENSITY_CODES, DOCK_ERROR_TO_TEXT, DOCK_TYPE_MAP, RoborockDockType, RoborockDockDustCollectionType, \
+    DUST_COLLECTION_MAP, WASH_MODE_MAP, RoborockDockWashingModeType
 
 
 class UserDataRRiotReferenceField(str, Enum):
@@ -225,8 +226,29 @@ class SmartWashField(str, Enum):
     WASH_INTERVAL = "wash_interval"
 
 
+class DustCollectionField(str, Enum):
+    MODE = "mode"
+
+
 class WashTowelField(str, Enum):
-    Wash_MODE = "wash_mode"
+    WASH_MODE = "wash_mode"
+
+
+class NetworkInfoField(str, Enum):
+    SSID = "ssid"
+    IP = "ip"
+    MAC = "mac"
+    BSSID = "bssid"
+    RSSI = "rssi"
+
+
+class RoborockDeviceInfoField(str, Enum):
+    DEVICE = "device"
+    PRODUCT = "product"
+
+
+class RoborockLocalDeviceInfoField(str, Enum):
+    NETWORK_INFO = "network_info"
 
 
 class RoborockBase(dict):
@@ -240,8 +262,6 @@ class RoborockBase(dict):
 
 
 class Reference(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def region(self) -> str:
@@ -261,8 +281,6 @@ class Reference(RoborockBase):
 
 
 class RRiot(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def user(self) -> str:
@@ -286,8 +304,6 @@ class RRiot(RoborockBase):
 
 
 class UserData(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def uid(self) -> int:
@@ -335,8 +351,6 @@ class UserData(RoborockBase):
 
 
 class LoginData(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def user_data(self) -> UserData:
@@ -356,8 +370,6 @@ class LoginData(RoborockBase):
 
 
 class HomeDataProductSchema(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def id(self):
@@ -389,8 +401,6 @@ class HomeDataProductSchema(RoborockBase):
 
 
 class HomeDataProduct(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def id(self) -> str:
@@ -430,8 +440,6 @@ class HomeDataProduct(RoborockBase):
 
 
 class HomeDataDeviceStatus(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def id(self):
@@ -471,8 +479,6 @@ class HomeDataDeviceStatus(RoborockBase):
 
 
 class HomeDataDevice(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def duid(self) -> str:
@@ -576,8 +582,6 @@ class HomeDataDevice(RoborockBase):
 
 
 class HomeDataRoom(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def id(self):
@@ -589,8 +593,6 @@ class HomeDataRoom(RoborockBase):
 
 
 class HomeData(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def id(self) -> int:
@@ -630,8 +632,6 @@ class HomeData(RoborockBase):
 
 
 class Status(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def msg_ver(self) -> int:
@@ -831,8 +831,6 @@ class Status(RoborockBase):
 
 
 class DNDTimer(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def start_hour(self) -> int:
@@ -856,8 +854,6 @@ class DNDTimer(RoborockBase):
 
 
 class CleanSummary(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def clean_time(self) -> int:
@@ -881,8 +877,6 @@ class CleanSummary(RoborockBase):
 
 
 class CleanRecord(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def begin(self) -> int:
@@ -938,8 +932,6 @@ class CleanRecord(RoborockBase):
 
 
 class Consumable(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def main_brush_work_time(self) -> int:
@@ -975,8 +967,6 @@ class Consumable(RoborockBase):
 
 
 class MultiMapsListMapInfoBakMaps(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def mapflag(self):
@@ -988,8 +978,6 @@ class MultiMapsListMapInfoBakMaps(RoborockBase):
 
 
 class MultiMapsListMapInfo(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def mapflag(self):
@@ -1013,8 +1001,6 @@ class MultiMapsListMapInfo(RoborockBase):
 
 
 class MultiMapsList(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def max_multi_map(self) -> int:
@@ -1034,8 +1020,6 @@ class MultiMapsList(RoborockBase):
 
 
 class SmartWashParameters(RoborockBase):
-    def __init__(self, data: dict[str, any]) -> None:
-        super().__init__(data)
 
     @property
     def smart_wash(self) -> int:
@@ -1044,3 +1028,55 @@ class SmartWashParameters(RoborockBase):
     @property
     def wash_interval(self) -> int:
         return self.get(SmartWashField.WASH_INTERVAL)
+
+
+class DustCollectionMode(RoborockBase):
+
+    @property
+    def mode(self) -> RoborockDockDustCollectionType:
+        return DUST_COLLECTION_MAP.get(self.get(DustCollectionField.MODE))
+
+
+class WashTowelMode(RoborockBase):
+
+    @property
+    def wash_mode(self) -> RoborockDockWashingModeType:
+        return WASH_MODE_MAP.get(self.get(WashTowelField.WASH_MODE))
+
+
+class NetworkInfo(RoborockBase):
+    @property
+    def ssid(self) -> str:
+        return self.get(NetworkInfoField.SSID)
+
+    @property
+    def ip(self) -> str:
+        return self.get(NetworkInfoField.IP)
+
+    @property
+    def mac(self) -> str:
+        return self.get(NetworkInfoField.MAC)
+
+    @property
+    def bssid(self) -> str:
+        return self.get(NetworkInfoField.BSSID)
+
+    @property
+    def rssi(self) -> int:
+        return self.get(NetworkInfoField.RSSI)
+
+
+class RoborockDeviceInfo(RoborockBase):
+    @property
+    def device(self) -> HomeDataDevice:
+        return HomeDataDevice(self.get(RoborockDeviceInfoField.DEVICE))
+
+    @property
+    def product(self) -> HomeDataProduct:
+        return HomeDataProduct(self.get(RoborockDeviceInfoField.PRODUCT))
+
+
+class RoborockLocalDeviceInfo(RoborockDeviceInfo):
+    @property
+    def network_info(self) -> NetworkInfo:
+        return NetworkInfo(self.get(RoborockLocalDeviceInfoField.NETWORK_INFO))
